[elpa] externals/cursory 45a1d36e64 3/5: Document some examples to use the cursory-set-preset-hook

2024-09-14 Thread ELPA Syncer
branch: externals/cursory
commit 45a1d36e642f23079682aeccebc9051cf8d7338f
Author: Protesilaos Stavrou 
Commit: Protesilaos Stavrou 

Document some examples to use the cursory-set-preset-hook
---
 README.org | 37 +
 1 file changed, 33 insertions(+), 4 deletions(-)

diff --git a/README.org b/README.org
index 7a26d3634d..e253784ffb 100644
--- a/README.org
+++ b/README.org
@@ -84,10 +84,12 @@ minibuffer completion when there are multiple presets, else 
sets the
 single preset outright.
 
 #+vindex: cursory-set-preset-hook
-The ~cursory-set-preset~ comman calls the ~cursory-set-preset-hook~
-as its final step.  Use this to run other functions after changing the
-cursor (e.g. a function that checks the style Cursory used to apply an
-appropriate color). [ This hook is part of {{{development-version}}}. ]
+#+vindex: cursory-last-selected-preset
+The ~cursory-set-preset~ comman calls the ~cursory-set-preset-hook~ as
+its final step. Use this to run other functions after changing the
+cursor ([[#h:035c0942-3163-436a-b0e3-67b1b669d109][Example hooks after setting 
a preset]]). The variable
+~cursory-last-selected-preset~ may prove useful. [ This hook is part
+of {{{development-version}}}. ]
 
 Presets consist of an arbitrary symbol broadly described the style set
 followed by a list of properties that govern the cursor type in the
@@ -215,6 +217,33 @@ Instead of manually storing the latest Cursory preset, 
users can
 enable the ~cursory-mode~. It arranges to track the latest preset each
 time after using ~cursory-set-preset~ or Emacs is closed.
 
+** Example hooks after setting a preset
+:PROPERTIES:
+:CUSTOM_ID: h:035c0942-3163-436a-b0e3-67b1b669d109
+:END:
+
+The ~cursory-set-preset-hook~ is a normal hook (where functions are
+called without any arguments), which is called after the command
+~cursory-set-preset~. Here are some ideas on how to use it:
+
+#+begin_src emacs-lisp
+;; Imagine you have a preset where you want minimal cursor styles.
+;; You call this `focus' and want when you switch to it to change the
+;; cursor color.
+(defun my-cursory-change-color ()
+"Change to a subtle color when the `focus' Cursory preset is selected."
+  (if (eq cursory-last-selected-preset 'focus)
+  (set-face-background 'cursor "#99")
+(face-spec-recalc 'cursor nil)))
+
+(defun my-cursory-change-color-disable-line-numbers ()
+  "Disable line numbers if the Cursory preset is `presentation' or `focus'."
+  (when (member cursory-last-selected-preset '(presentation focus))
+(display-line-numbers-mode -1)))
+#+end_src
+
+I am happy to include more examples here, if users have any questions.
+
 * Installation
 :PROPERTIES:
 :CUSTOM_ID: h:6dd596f2-d98b-4275-b25e-495e2a0616bf



[elpa] externals/cursory updated (d079b397ba -> a9076f6a0f)

2024-09-14 Thread ELPA Syncer
elpasync pushed a change to branch externals/cursory.

  from  d079b397ba Update source links to point to GitHub
   new  5d5c644212 Reword a statement in the manual
   new  c9686b2658 Store the selected preset in a variable
   new  45a1d36e64 Document some examples to use the cursory-set-preset-hook
   new  9c5bb8122d Update to Cursory version 1.1.0
   new  a9076f6a0f Use memq instead of member in one example


Summary of changes:
 CHANGELOG.org | 92 ---
 README.org| 50 
 cursory.el|  6 +++-
 3 files changed, 131 insertions(+), 17 deletions(-)



[elpa] externals/cursory c9686b2658 2/5: Store the selected preset in a variable

2024-09-14 Thread ELPA Syncer
branch: externals/cursory
commit c9686b2658b0434e811afccd83fc718806497c2b
Author: Protesilaos Stavrou 
Commit: Protesilaos Stavrou 

Store the selected preset in a variable
---
 cursory.el | 4 
 1 file changed, 4 insertions(+)

diff --git a/cursory.el b/cursory.el
index da7d7e56a6..1f8f2bd984 100644
--- a/cursory.el
+++ b/cursory.el
@@ -311,6 +311,9 @@ Saving is done by the `cursory-store-latest-preset' 
function."
   blink-cursor-delay))
 (kill-local-variable var)))
 
+(defvar cursory-last-selected-preset nil
+  "The last value of `cursory-set-preset'.")
+
 (defun cursory--set-preset-with-scope (preset &optional local)
   "Set PRESET of `cursory-presets' to the global scope.
 With optional non-nil LOCAL, set STYLES scoped locally to the
@@ -323,6 +326,7 @@ current buffer."
 (blinks (plist-get styles :blink-cursor-blinks))
 (interval (plist-get styles :blink-cursor-interval))
 (delay (plist-get styles :blink-cursor-delay)))
+(setq cursory-last-selected-preset preset)
 (if local
 (setq-local cursor-type type
 cursor-in-non-selected-windows type-no-select



[elpa] externals/cursory 5d5c644212 1/5: Reword a statement in the manual

2024-09-14 Thread ELPA Syncer
branch: externals/cursory
commit 5d5c644212faff57e6752839919e0eb93a7a1415
Author: Protesilaos Stavrou 
Commit: Protesilaos Stavrou 

Reword a statement in the manual
---
 README.org | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/README.org b/README.org
index 4b1e6b886a..7a26d3634d 100644
--- a/README.org
+++ b/README.org
@@ -212,8 +212,8 @@ be restored with the ~cursory-restore-latest-preset~ 
function.
 [ The following is part of {{{development-version}}}. ]
 
 Instead of manually storing the latest Cursory preset, users can
-enable the ~cursory-mode~. It arranges to track the latest preset
-after using ~cursory-set-preset~ or closing Emacs.
+enable the ~cursory-mode~. It arranges to track the latest preset each
+time after using ~cursory-set-preset~ or Emacs is closed.
 
 * Installation
 :PROPERTIES:



[elpa] externals/cursory 9c5bb8122d 4/5: Update to Cursory version 1.1.0

2024-09-14 Thread ELPA Syncer
branch: externals/cursory
commit 9c5bb8122d5780796b881da6d37442e532ba6c51
Author: Protesilaos Stavrou 
Commit: Protesilaos Stavrou 

Update to Cursory version 1.1.0
---
 CHANGELOG.org | 92 ---
 README.org| 15 --
 cursory.el|  2 +-
 3 files changed, 95 insertions(+), 14 deletions(-)

diff --git a/CHANGELOG.org b/CHANGELOG.org
index 023861db77..cfe722209c 100644
--- a/CHANGELOG.org
+++ b/CHANGELOG.org
@@ -1,7 +1,9 @@
-#+TITLE: Change log of cursory.el
-#+AUTHOR: Protesilaos Stavrou
-#+EMAIL: i...@protesilaos.com
-#+OPTIONS: ':nil toc:nil num:nil author:nil email:nil
+#+title: Change log of cursory.el
+#+author: Protesilaos Stavrou
+#+email: i...@protesilaos.com
+#+language: en
+#+options: ':t toc:nil author:t email:t num:t
+#+startup: content
 
 This document contains the release notes for each tagged commit on the
 project's main git repository: .
@@ -9,6 +11,88 @@ project's main git repository: 
.
 The newest release is at the top.  For further details, please consult
 the manual: .
 
+#+toc: headlines 1 insert TOC here, with one headline level
+
+* Version 1.1.0 on 2024-09-14
+:PROPERTIES:
+:CUSTOM_ID: h:475f025a-fa3d-4709-884f-bd0b32dc78cc
+:END:
+
+Cursory is in a stable state. This version includes quality-of-life
+refinements.
+
+** The ~cursory-mode~ simplifies how the state is stored
+:PROPERTIES:
+:CUSTOM_ID: h:d2ccd7ea-2379-40d2-b329-3e5d6ab2686c
+:END:
+
+Cursory has functions to store and restore its state. In previous
+versions, we would document how to use those by adding them to the
+relevant hooks. This approach still works, though we now provide an
+easier way to achieve the same result: just enable the ~cursory-mode~.
+
+Technically, all this does is to set the hooks if enabled, and unsets
+them if disabled.
+
+The "restore" phase is the same as before. For example:
+
+#+begin_src emacs-lisp
+;; Set last preset, if available, or fall back to the `bar' preset
+;; from the `cursory-presets'.
+(cursory-set-preset (or (cursory-restore-latest-preset) 'bar))
+#+end_src
+
+** Use the ~cursory-set-preset-hook~
+:PROPERTIES:
+:CUSTOM_ID: h:d60030aa-cfa2-4d94-9757-bbd783cbb7fd
+:END:
+
+The ~cursory-set-preset-hook~ is a normal hook (where functions are
+invoked without any arguments), which is called after the command
+~cursory-set-preset~. Here are some ideas on how to use it:
+
+#+begin_src emacs-lisp
+;; Imagine you have a preset where you want minimal cursor styles.
+;; You call this `focus' and want when you switch to it to change the
+;; cursor color.
+(defun my-cursory-change-color ()
+"Change to a subtle color when the `focus' Cursory preset is selected."
+  (if (eq cursory-last-selected-preset 'focus)
+  (set-face-background 'cursor "#99")
+(face-spec-recalc 'cursor nil)))
+
+;; Here we just show how to disable a given mode.  Of course, we can
+;; have something more sophisticated, which stores the last value and
+;; restores it if the condition we are testing for here is not met.
+;; Keeping it simple for now.
+(defun my-cursory-change-color-disable-line-numbers ()
+  "Disable line numbers if the Cursory preset is `presentation' or `focus'."
+  (when (member cursory-last-selected-preset '(presentation focus))
+(display-line-numbers-mode -1)))
+#+end_src
+
+I am happy to include more examples here, if users have any questions.
+
+** Miscellaneous
+:PROPERTIES:
+:CUSTOM_ID: h:c7233f22-1610-430c-a60a-1cd9168ae624
+:END:
+
+- Fixed a dependency for older Emacs versions. The ~subr-x~, which is
+  built into Emacs, needs to be explicitly loaded at compile time.
+  This makes some parts of the code work as expected. Thanks to Mehdi
+  Khawari for reporting the problem and Nicholas Vollmer for
+  suggesting this change. The exchange took place in issue 1:
+  . Users should
+  already have this change, as I published a minor release for it
+  (version =1.0.1=).
+
+- Added some missing metadata to the manual. This is useful for the
+  indices and COPYING section.
+
+- Updated the relevant links to the package sources. The main
+  repository is now on GitHub.
+
 * Version 1.0.0 on 2023-06-09
 :PROPERTIES:
 :CUSTOM_ID: h:9fed228e-cde0-4d23-952a-937301b82b22
diff --git a/README.org b/README.org
index e253784ffb..5061f73a8c 100644
--- a/README.org
+++ b/README.org
@@ -4,9 +4,9 @@
 #+language: en
 #+options: ':t toc:nil author:t email:t num:t
 #+startup: content
-#+macro: stable-version 1.0.0
-#+macro: release-date 2023-06-09
-#+macro: development-version 1.1.0-dev
+#+macro: stable-version 1.1.0
+#+macro: release-date 2024-09-14
+#+macro: development-version 1.2.0-dev
 #+macro: file @@texinfo:@file{@@$1@@texinfo:}@@
 #+macro: space @@texinfo:@: @@
 #+macro: kbd @@texinfo:@kbd{@@$1@@texinfo:}@@
@@ -49,7 +49,7 @@ Current development target is {{{deve

[elpa] externals/cursory a9076f6a0f 5/5: Use memq instead of member in one example

2024-09-14 Thread ELPA Syncer
branch: externals/cursory
commit a9076f6a0f06ec4f0f572aaf3a4d318959bac918
Author: Protesilaos Stavrou 
Commit: Protesilaos Stavrou 

Use memq instead of member in one example
---
 README.org | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/README.org b/README.org
index 5061f73a8c..f96ae223d7 100644
--- a/README.org
+++ b/README.org
@@ -235,7 +235,7 @@ invoked without any arguments), which is called after the 
command
 
 (defun my-cursory-change-color-disable-line-numbers ()
   "Disable line numbers if the Cursory preset is `presentation' or `focus'."
-  (when (member cursory-last-selected-preset '(presentation focus))
+  (when (memq cursory-last-selected-preset '(presentation focus))
 (display-line-numbers-mode -1)))
 #+end_src
 



[elpa] externals/greader a9628d29f6: greader-espeak.el: toggle punctuation fixed.

2024-09-14 Thread ELPA Syncer
branch: externals/greader
commit a9628d29f642f6ea8f1ed2c0778b3e8073fff867
Author: Michelangelo Rodriguez 
Commit: Michelangelo Rodriguez 

greader-espeak.el: toggle punctuation fixed.
---
 greader-espeak.el | 4 ++--
 greader.el| 2 +-
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/greader-espeak.el b/greader-espeak.el
index ea8a931bef..5fd97d18de 100644
--- a/greader-espeak.el
+++ b/greader-espeak.el
@@ -67,10 +67,10 @@ LANG must be recognized by espeak or espeak-ng."
   (setq-local greader-espeak-language lang)
   (concat "-v " lang
 
-(defvar greader-espeak--punctuation-ring (make-ring 2))
+(defvar-local  greader-espeak--punctuation-ring (make-ring 2))
 (ring-insert greader-espeak--punctuation-ring "yes")
 (ring-insert greader-espeak--punctuation-ring "no")
-(defvar greader-espeak--ring-item (if greader-espeak-punctuation "yes"
+(defvar-local greader-espeak--ring-item (if greader-espeak-punctuation "yes"
"no"))
 
 ;;;###autoload
diff --git a/greader.el b/greader.el
index 66ab7f053f..f39e2a0508 100644
--- a/greader.el
+++ b/greader.el
@@ -7,7 +7,7 @@
 ;; Keywords: tools, accessibility
 ;; URL: https://gitlab.com/michelangelo-rodriguez/greader
 
-;; Version: 0.11.16
+;; Version: 0.11.17
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by



[elpa] externals/cape 75b7cf7c76: cape-company-to-capf: Minor code cleanup

2024-09-14 Thread ELPA Syncer
branch: externals/cape
commit 75b7cf7c76cc3fca2c0adb54323a6300fe16e1a3
Author: Daniel Mendler 
Commit: Daniel Mendler 

cape-company-to-capf: Minor code cleanup
---
 cape.el | 7 +++
 1 file changed, 3 insertions(+), 4 deletions(-)

diff --git a/cape.el b/cape.el
index 278e2db44a..202292d975 100644
--- a/cape.el
+++ b/cape.el
@@ -845,10 +845,9 @@ again if the input prefix changed."
  (lambda (input)
(let ((cands (cape--company-call backend 'candidates 
input)))
  ;; The candidate string including text properties should 
be
- ;; restored in the :exit-function, if the UI does not
- ;; guarantee this itself.  Restoration is not necessary 
for
- ;; Corfu since the introduction of `corfu--exit-function'.
- (unless (and (bound-and-true-p corfu-mode) (fboundp 
'corfu--exit-function))
+ ;; restored in the :exit-function, unless the UI 
guarantees
+ ;; this itself, like Corfu.
+ (unless (bound-and-true-p corfu-mode)
(setq restore-props cands))
  (cons (apply-partially valid input) cands
 :category backend



[elpa] externals/dape 71057c1ec4 2/4: Improve comment

2024-09-14 Thread ELPA Syncer
branch: externals/dape
commit 71057c1ec405d25923286f086478fc41e033ade4
Author: Daniel Pettersson 
Commit: Daniel Pettersson 

Improve comment
---
 dape.el | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/dape.el b/dape.el
index 71711c8cd1..886e00263a 100644
--- a/dape.el
+++ b/dape.el
@@ -2540,11 +2540,11 @@ When SKIP-UPDATE is non nil, does not notify adapter 
about removal."
   (current-thread (dape--current-thread conn))
   (collection
(let (done)
- ;; Need to fetch all frames as might only have 1 frame
- ;; fetches see `dape--stack-trace' and
- ;; `:supportsDelayedStackTraceLoading'.
  (dape--with-request
  (dape--stack-trace conn current-thread 
dape-stack-trace-levels)
+ ;; Only one stack frame is guaranteed to be available,
+ ;; so we need to reach out to make sure we got the full set.
+ ;; See `dape--stack-trace'.
(setf done t))
  (with-timeout (5 nil)
(while (not done) (accept-process-output nil 0.1)))



[elpa] externals/dape 056125fcf9 1/4: Add usable default value for dape

2024-09-14 Thread ELPA Syncer
branch: externals/dape
commit 056125fcf91e28b765a28063bf7b1e27661683c3
Author: Daniel Pettersson 
Commit: Daniel Pettersson 

Add usable default value for dape

Suggested config name as default value to ease resetting config
parameters
---
 dape.el | 8 ++--
 1 file changed, 6 insertions(+), 2 deletions(-)

diff --git a/dape.el b/dape.el
index 05148dcb2e..71711c8cd1 100644
--- a/dape.el
+++ b/dape.el
@@ -5216,7 +5216,9 @@ See `dape--config-mode-p' how \"valid\" is defined."
  dape-history)
;; Take first suggested config if only one exist
(and (length= suggested-configs 1)
-(car suggested-configs)
+(car suggested-configs
+ (default-value (when initial-contents
+  (concat (car (string-split initial-contents)) " "
 (setq dape--minibuffer-last-buffer (current-buffer)
   dape--minibuffer-cache nil)
 (minibuffer-with-setup-hook
@@ -5248,6 +5250,8 @@ See `dape--config-mode-p' how \"valid\" is defined."
  (set-keymap-parent map minibuffer-local-map)
  (define-key map (kbd "C-M-i") #'completion-at-point)
  (define-key map "\t" #'completion-at-point)
+ ;; This mapping is shadowed by `next-history-element'
+ ;; future history (default-value)
  (define-key map (kbd "C-c C-k")
  (lambda ()
(interactive)
@@ -5259,7 +5263,7 @@ See `dape--config-mode-p' how \"valid\" is defined."
 (point-max))
  (insert (format "%s" key) " "
  map)
-   nil 'dape-history initial-contents)))
+   nil 'dape-history default-value)))
(`(,key ,config)
 (dape--config-from-string (substring-no-properties str) t))
(evaled-config (dape--config-eval key config)))



[elpa] externals/consult 73530bab90: Remove with-delayed-message workaround

2024-09-14 Thread ELPA Syncer
branch: externals/consult
commit 73530bab90dae79d6b0ea177b4e935588ea08dd1
Author: Daniel Mendler 
Commit: Daniel Mendler 

Remove with-delayed-message workaround
---
 consult.el | 6 ++
 1 file changed, 2 insertions(+), 4 deletions(-)

diff --git a/consult.el b/consult.el
index c3cdfb7a2c..ea440c1cf8 100644
--- a/consult.el
+++ b/consult.el
@@ -915,10 +915,8 @@ always return an appropriate non-minibuffer window."
   "Show delayed MESSAGE if BODY takes too long.
 Also temporarily increase the GC limit via `consult--with-increased-gc'."
   (declare (indent 1))
-  `(let (set-message-function) ;; bug#63253: Broken `with-delayed-message'
- (with-delayed-message (1 ,message)
-   (consult--with-increased-gc
-,@body
+  `(with-delayed-message (1 ,message)
+ (consult--with-increased-gc ,@body)))
 
 (defun consult--count-lines (pos)
   "Move to position POS and return number of lines."



[elpa] externals/dape 22dcbbaa1e 4/4: Fix formatting

2024-09-14 Thread ELPA Syncer
branch: externals/dape
commit 22dcbbaa1e64d7e549bb1e7dcddc6472140af881
Author: Daniel Pettersson 
Commit: Daniel Pettersson 

Fix formatting
---
 dape.el | 18 --
 1 file changed, 8 insertions(+), 10 deletions(-)

diff --git a/dape.el b/dape.el
index 07bb96c008..192da3422e 100644
--- a/dape.el
+++ b/dape.el
@@ -3898,8 +3898,7 @@ See `dape-request' for expected CB signature."
 Create table from CURRENT-STACK-FRAME and STACK-FRAMES and insert into
 current buffer with CONN config."
   (cl-loop with table = (make-gdb-table)
-   for frame in stack-frames
-   do
+   for frame in stack-frames do
(gdb-table-add-row
 table
 (list
@@ -4049,14 +4048,13 @@ current buffer with CONN config."
  dape--connection)))
   (cl-loop with sources = (dape--sources conn)
with table = (make-gdb-table)
-   for source in (reverse sources)
-   do (gdb-table-add-row table
- (list (concat (plist-get source :name) " 
"))
- (list
-  'dape--info-source source
-  'mouse-face 'highlight
-  'keymap dape-info-sources-line-map
-  'help-echo "mouse-2, RET: goto source"))
+   for source in (reverse sources) do
+   (gdb-table-add-row
+table (list (concat (plist-get source :name) " "))
+(list 'dape--info-source source
+  'mouse-face 'highlight
+  'keymap dape-info-sources-line-map
+  'help-echo "mouse-2, RET: goto source"))
finally (insert (gdb-table-string table " "))
 
 



[elpa] externals/dape updated (cc83e6ea9b -> 22dcbbaa1e)

2024-09-14 Thread ELPA Syncer
elpasync pushed a change to branch externals/dape.

  from  cc83e6ea9b Add bash-debug
   new  056125fcf9 Add usable default value for dape
   new  71057c1ec4 Improve comment
   new  c1301d238a Fix dropped line arrow due to delayed stack frame 
fetching
   new  22dcbbaa1e Fix formatting


Summary of changes:
 dape.el | 166 ++--
 1 file changed, 88 insertions(+), 78 deletions(-)



[elpa] externals/dape c1301d238a 3/4: Fix dropped line arrow due to delayed stack frame fetching

2024-09-14 Thread ELPA Syncer
branch: externals/dape
commit c1301d238af5417e394b15b53db4bd1ab54ab0fc
Author: Daniel Pettersson 
Commit: Daniel Pettersson 

Fix dropped line arrow due to delayed stack frame fetching

When supportsDelayedStackTraceLoading is used and deepest stack frame
is not displayable dape--stack-frame-display failed to display any
frame.

If frame display candidate is not found make sure that the rest of the
frames are fetched as well.
---
 dape.el | 134 ++--
 1 file changed, 71 insertions(+), 63 deletions(-)

diff --git a/dape.el b/dape.el
index 886e00263a..07bb96c008 100644
--- a/dape.el
+++ b/dape.el
@@ -3233,72 +3233,80 @@ See `dape-request' for expected CB signature."
 (delete-overlay dape--stack-position-overlay))
   (set-marker dape--overlay-arrow-position nil))
 
+(defun dape--stack-frame-display-1 (conn frame deepest-p)
+  "Display FRAME for adapter CONN as if DEEPEST-p.
+Helper for `dape--stack-frame-display'."
+  (dape--with-request (dape--source-ensure conn frame)
+;; An update event could have fired between call to
+;; `dape--stack-frame-cleanup' and callback, we have make sure
+;; that overlay is deleted before we are dropping the overlay
+;; reference
+(dape--stack-frame-cleanup)
+(when-let ((marker (dape--object-to-marker conn frame)))
+  (with-current-buffer (marker-buffer marker)
+(dape--add-eldoc-hook)
+(save-excursion
+  (goto-char (marker-position marker))
+  (setq dape--stack-position-overlay
+(let ((ov (make-overlay (line-beginning-position)
+(line-beginning-position 2
+  (overlay-put ov 'face 'dape-source-line-face)
+  (when deepest-p
+(when-let ((exception-description
+(dape--exception-description conn)))
+  (overlay-put ov 'after-string
+   (propertize (concat exception-description 
"\n")
+   'face
+   
'dape-exception-description-face
+  ov)
+fringe-indicator-alist
+(unless deepest-p
+  '((overlay-arrow . hollow-right-triangle
+  ;; Finally lets move arrow to point
+  (move-marker dape--overlay-arrow-position
+   (line-beginning-position)))
+(when-let ((window
+(display-buffer (marker-buffer marker)
+dape-display-source-buffer-action)))
+  ;; Change selected window if not `dape-repl' buffer is selected
+  (unless (with-current-buffer (window-buffer)
+(memq major-mode '(dape-repl-mode)))
+(select-window window))
+  (with-selected-window window
+;; XXX: This code is running within timer context, which
+;;  does not play nice with `post-command-hook'.
+;;  Since hooks are runn'ed before the point is
+;;  actually moved.
+(goto-char (marker-position marker))
+;; Here we are manually intervening to account for this.
+;; The following logic borrows from gud.el to interact
+;; with `hl-line'.
+(when (featurep 'hl-line)
+ (cond
+   (global-hl-line-mode (global-hl-line-highlight))
+  ((and hl-line-mode hl-line-sticky-flag) (hl-line-highlight
+(run-hooks 'dape-display-source-hook)))
+
 (defun dape--stack-frame-display (conn)
   "Update stack frame arrow marker for adapter CONN.
-`dape-display-source-buffer-action'."
+Buffer is displayed with `dape-display-source-buffer-action'."
   (dape--stack-frame-cleanup)
-  (when-let* (((dape--stopped-threads conn))
-  (frames (plist-get (dape--current-thread conn) :stackFrames))
-  (selected (dape--current-stack-frame conn))
-  (frame (cl-loop for cell on frames for (frame) = cell
-  when (eq frame selected) return
-  (cl-loop for frame in cell when
-   (dape--source conn frame)
-   return frame
-(let ((deepest-p (eq selected (car frames
-  (dape--with-request (dape--source-ensure conn frame)
-;; An update event could have fired between call to
-;; `dape--stack-frame-cleanup' and callback, we have make
-;; sure that overlay is deleted before we are dropping the
-;; reference
-(dape--stack-frame-cleanup)
-(when-let ((marker (dape--object-to-marker conn frame)))
-  (with-current-buffer (marker-buffer marker)
-(dape--add-eldoc-hook)
-(save-excursion
-  (goto-char (mark

[elpa] externals/jinx 45961dfdb2: Remove with-delayed-message workaround

2024-09-14 Thread ELPA Syncer
branch: externals/jinx
commit 45961dfdb2a56573af6e06d023e262530d60c09d
Author: Daniel Mendler 
Commit: Daniel Mendler 

Remove with-delayed-message workaround
---
 jinx.el | 9 -
 1 file changed, 4 insertions(+), 5 deletions(-)

diff --git a/jinx.el b/jinx.el
index 18d7345397..c0bc6f6e45 100644
--- a/jinx.el
+++ b/jinx.el
@@ -513,11 +513,10 @@ If VISIBLE is non-nil, only include visible overlays.
 If CHECK is non-nil, always check first."
   (or (and (not check) (jinx--get-overlays start end visible))
   (progn
-(let (set-message-function) ;; bug#63253: Broken `with-delayed-message'
-  (with-delayed-message (1 "Fontifying...")
-(jinx--in-base-buffer #'jit-lock-fontify-now start end))
-  (with-delayed-message (1 "Checking...")
-(jinx--check-region start end)))
+(with-delayed-message (1 "Fontifying...")
+  (jinx--in-base-buffer #'jit-lock-fontify-now start end))
+(with-delayed-message (1 "Checking...")
+  (jinx--check-region start end))
 (jinx--get-overlays start end visible))
   (user-error (if visible "No misspelled word in visible text"
 "No misspelled word in whole buffer"



[elpa] externals/phpinspect updated (4041796ee0 -> f3a273baf5)

2024-09-14 Thread ELPA Syncer
elpasync pushed a change to branch externals/phpinspect.

  from  4041796ee0 Fix compilation errors (move 
`phpinspect-project-read-type-name' to phpinspect-imports.el)
   new  d92f48de6e Increase number of nodes in splay-tree benchmark
   new  effc24c674 Add explanatory comment in phpinspect-buffer.el
   new  964b9d3c21 Fix bug in parser that caused end-of-buffer error while 
parsing comments delimited by max-point
   new  f3a273baf5 Don't complete words within comments


Summary of changes:
 benchmarks/splay-tree.el | 119 ---
 phpinspect-buffer.el |   8 +++-
 phpinspect-completion.el |  41 ++--
 phpinspect-meta.el   |   7 +++
 phpinspect-parser.el |  21 +
 test/test-completion.el  |  25 ++
 test/test-parser.el  |   5 ++
 7 files changed, 122 insertions(+), 104 deletions(-)



[elpa] externals/phpinspect 964b9d3c21 3/4: Fix bug in parser that caused end-of-buffer error while parsing comments delimited by max-point

2024-09-14 Thread ELPA Syncer
branch: externals/phpinspect
commit 964b9d3c21fe91081d9507d6586817e6917cf682
Author: Hugo Thunnissen 
Commit: Hugo Thunnissen 

Fix bug in parser that caused end-of-buffer error while parsing comments 
delimited by max-point
---
 phpinspect-parser.el | 21 -
 test/test-parser.el  |  5 +
 2 files changed, 17 insertions(+), 9 deletions(-)

diff --git a/phpinspect-parser.el b/phpinspect-parser.el
index f34262f4df..a3b9480237 100644
--- a/phpinspect-parser.el
+++ b/phpinspect-parser.el
@@ -546,26 +546,30 @@ nature like argument lists"
 
   (cond ((string-match "/\\*" start-token)
  (let* ((region-start (point))
+(found-delimiter nil)
 ;; Move to the end of the comment region
 (region-end
  (progn
-   (while (not (or (= max-point (point)) (looking-at "\\*/")))
+   (while (not (or (= max-point (point))
+   (and (looking-at "\\*/") (setq 
found-delimiter t
  (forward-char))
(point)))
 (doc-block (save-restriction
  (goto-char region-start)
  (narrow-to-region region-start region-end)
  (phpinspect--parse-doc-block (current-buffer) 
(point-max)
-   (forward-char 2)
+   ;; If a delimiter (*/) was found, skip over it.
+   (when found-delimiter
+ (forward-char 2))
doc-block))
 (t
  (let* ((end-position (line-end-position))
-   (token
-(phpinspect--parse-comment (current-buffer) end-position 1)))
-  ;; Move to start of next line (absorb end of line)
-  (while (not (bolp))
-(forward-char))
-  token
+   (token
+(phpinspect--parse-comment (current-buffer) 
end-position)))
+  ;; Move to start of next line (absorb end of line)
+  (while (not (or (bolp) (= max-point (point
+(forward-char))
+  token
 
 (phpinspect-defhandler class-variable (start-token &rest _ignored)
   "Handler for tokens indicating reference to a variable"
@@ -575,7 +579,6 @@ nature like argument lists"
   (phpinspect-munch-token-without-attribs (match-string 0) :class-variable)
 (list :class-variable nil)))
 
-
 (phpinspect-defhandler whitespace (whitespace &rest _ignored)
   "Handler that discards whitespace"
   ((regexp . "[[:blank:]\n]+"))
diff --git a/test/test-parser.el b/test/test-parser.el
index 741a65b4ee..573854333d 100644
--- a/test/test-parser.el
+++ b/test/test-parser.el
@@ -195,3 +195,8 @@ interface Test
   (:terminator ";"))
 
 (should (equal expected result
+
+(ert-deftest phpinspect-parse-incomplete-comments ()
+  (dolist (code (list "//" "/*" "// " "/* "))
+
+(should (phpinspect-parse-string code



[elpa] externals/phpinspect d92f48de6e 1/4: Increase number of nodes in splay-tree benchmark

2024-09-14 Thread ELPA Syncer
branch: externals/phpinspect
commit d92f48de6e39bac71e7fe3b06affddbaa87e804e
Author: Hugo Thunnissen 
Commit: Hugo Thunnissen 

Increase number of nodes in splay-tree benchmark
---
 benchmarks/splay-tree.el | 119 ---
 1 file changed, 40 insertions(+), 79 deletions(-)

diff --git a/benchmarks/splay-tree.el b/benchmarks/splay-tree.el
index d2ca0d2a63..04792fb1d4 100644
--- a/benchmarks/splay-tree.el
+++ b/benchmarks/splay-tree.el
@@ -24,48 +24,47 @@
 
 
 (require 'phpinspect-splayt)
-
-(defun swap (LIST el1 el2)
-  "in LIST swap indices EL1 and EL2 in place"
-  (let ((tmp (elt LIST el1)))
-(setf (elt LIST el1) (elt LIST el2))
-(setf (elt LIST el2) tmp)))
-
-(defun shuffle (LIST)
-  "Shuffle the elements in LIST.
-shuffling is done in place."
-  (cl-loop for i in (reverse (number-sequence 1 (1- (length LIST
-do (let ((j (random (+ i 1
- (swap LIST i j)))
-  LIST)
-
-(defconst phpi-randomized-access (shuffle (number-sequence 1 1)))
-(defconst phpi-interval-access (number-sequence 1 1 50))
+(message "starting bench")
+
+(defun shuffle (list)
+  (let* ((vec (seq-into list 'vector))
+ (length (length vec))
+ (n 0))
+(while (< n length)
+  (let ((i (+ n (random (- length n
+(tmp (aref vec n)))
+(setf (aref vec n) (aref vec i)
+  (aref vec i) tmp))
+  (cl-incf n))
+(seq-into vec 'list)))
+
+(defconst phpi-randomized-access (shuffle (number-sequence 1 100)))
+(defconst phpi-interval-access (number-sequence 1 100 50))
 
 (let ((tree (phpinspect-make-splayt))
   result)
-  (message "Splay tree 1 insertions:")
+  (message "Splay tree 100 insertions:")
   (garbage-collect)
 
   (setq result
 (benchmark-run 1
-  (dotimes (i 1)
+  (dotimes (i 100)
 (phpinspect-splayt-insert tree i 'value
 
   (message "Elapsed time: %f (%f in %d GC's)"
(car result) (caddr result) (cadr result))
 
-  (message "Splay tree 1 lookups:")
+  (message "Splay tree 100 lookups:")
   (garbage-collect)
   (setq result
 (benchmark-run 1
-  (dotimes (i 1)
+  (dotimes (i 100)
 (phpinspect-splayt-find tree i
 
   (message "Elapsed time: %f (%f in %d GC's)"
(car result) (caddr result) (cadr result))
 
-  (message "Splay tree 1 randomized lookups:")
+  (message "Splay tree 100 randomized lookups:")
   (garbage-collect)
   (setq result
 (benchmark-run 1
@@ -75,11 +74,11 @@ shuffling is done in place."
   (message "Elapsed time: %f (%f in %d GC's)"
(car result) (caddr result) (cadr result))
 
-  (message "Splay tree 1 repeated (constant number 5) lookups:")
+  (message "Splay tree 100 repeated (constant number 5) lookups:")
   (garbage-collect)
   (setq result
 (benchmark-run 1
-  (dotimes (_i 1)
+  (dotimes (_i 100)
 (phpinspect-splayt-find tree 5
 
   (message "Elapsed time: %f (%f in %d GC's)"
@@ -97,7 +96,7 @@ shuffling is done in place."
   (message "Elapsed time: %f (%f in %d GC's)"
(car result) (caddr result) (cadr result))
 
-  (message "Splay tree 1 items traversal:")
+  (message "Splay tree 100 items traversal:")
   (garbage-collect)
   (setq result
 (benchmark-run 1
@@ -108,7 +107,7 @@ shuffling is done in place."
(car result) (caddr result) (cadr result))
 
 
-  (message "Splay tree 1 items LR traversal:")
+  (message "Splay tree 100 items LR traversal:")
   (garbage-collect)
   (setq result
 (benchmark-run 1
@@ -120,29 +119,29 @@ shuffling is done in place."
 
 
 (let (map result)
-  (message "Hashtable 1 insertions:")
+  (message "Hashtable 100 insertions:")
   (garbage-collect)
   (setq result
 (benchmark-run 1
   (progn
-(setq map (make-hash-table :test #'eq :size 1 :rehash-size 
1.5))
-(dotimes (i 1)
+(setq map (make-hash-table :test #'eq :size 100 :rehash-size 
1.5))
+(dotimes (i 100)
   (puthash i 'value map)
   (message "Elapsed time: %f (%f in %d GC's)"
(car result) (caddr result) (cadr result))
 
-  (message "Hashtable 1 lookups:")
+  (message "Hashtable 100 lookups:")
   (garbage-collect)
   (setq result
 (benchmark-run 1
-  (dotimes (i 1)
+  (dotimes (i 100)
 (ignore (gethash i map)
 
   (message "Elapsed time: %f (%f in %d GC's)"
(car result) (caddr result) (cadr result))
 
 
-  (message "Hashtable 1 iterations:")
+  (message "Hashtable 100 iterations:")
   (garbage-collect)
   (setq result
 (benchmark-run 1
@@ -155,28 +154,28 @@ shuffling is done in place."
 (require 'avl-tree)
 (let ((avl-tree (avl-tree-create #'car-less-than-car))
   result)
-  (message "AVL tree 1 insertions:")
+  (mes

[elpa] externals/phpinspect effc24c674 2/4: Add explanatory comment in phpinspect-buffer.el

2024-09-14 Thread ELPA Syncer
branch: externals/phpinspect
commit effc24c674d22846555ffd92ca46a95bce6c6ade
Author: Hugo Thunnissen 
Commit: Hugo Thunnissen 

Add explanatory comment in phpinspect-buffer.el
---
 phpinspect-buffer.el | 4 
 1 file changed, 4 insertions(+)

diff --git a/phpinspect-buffer.el b/phpinspect-buffer.el
index 515fae3485..2d4e54d209 100644
--- a/phpinspect-buffer.el
+++ b/phpinspect-buffer.el
@@ -299,6 +299,10 @@ linked with."
   (dolist (deleted deleted-classes)
 (if (and (setq class (phpinspect-buffer-get-index-for-token
   buffer (phpinspect-meta-token deleted)))
+ ;; If we can find a declaration in the buffer that is 
equal
+ ;; to the deleted declaration, the class has just been
+ ;; edited in a way were the declaration ended up getting
+ ;; reparsed. No need to delete it from the index
  (setq replaced (assoc (phpi-typedef-declaration class) 
new-declarations #'equal)))
 (pcase-let ((`(,imports ,namespace-name) 
(phpinspect-get-token-index-context namespaces buffer-imports (cdr replaced
   (phpinspect-buffer-update-index-reference-for-token



[elpa] externals/phpinspect f3a273baf5 4/4: Don't complete words within comments

2024-09-14 Thread ELPA Syncer
branch: externals/phpinspect
commit f3a273baf5152b525035dc10e37a9fa35c4853d0
Author: Hugo Thunnissen 
Commit: Hugo Thunnissen 

Don't complete words within comments
---
 phpinspect-buffer.el |  4 +++-
 phpinspect-completion.el | 41 ++---
 phpinspect-meta.el   |  7 +++
 test/test-completion.el  | 25 +
 4 files changed, 61 insertions(+), 16 deletions(-)

diff --git a/phpinspect-buffer.el b/phpinspect-buffer.el
index 2d4e54d209..4827be6c5f 100644
--- a/phpinspect-buffer.el
+++ b/phpinspect-buffer.el
@@ -584,7 +584,9 @@ continuing execution."
   (phpinspect-edtrack-register-edit
(phpinspect-buffer-edit-tracker buffer) start end pre-change-length))
 
-(cl-defmethod phpinspect-buffer-tokens-enclosing-point ((buffer 
phpinspect-buffer) point)
+(defun phpinspect-buffer-tokens-enclosing-point (buffer point)
+  "Return token metadata objects for tokens enclosing POINT in BUFFER."
+  (cl-assert (phpinspect-buffer-p buffer))
   (phpinspect-bmap-tokens-overlapping (phpinspect-buffer-map buffer) point))
 
 (cl-defmethod phpinspect-buffer-token-meta ((buffer phpinspect-buffer) token)
diff --git a/phpinspect-meta.el b/phpinspect-meta.el
index 49bdce9ba1..f0d0765c94 100644
--- a/phpinspect-meta.el
+++ b/phpinspect-meta.el
@@ -282,6 +282,13 @@
 (cl-defmethod phpinspect-meta-first-child ((meta (head meta)))
   (phpinspect-meta-find-child-after meta (- (phpinspect-meta-start meta) 1)))
 
+(defun phpinspect-meta-token-predicate (token-predicate)
+  "Wrap TOKEN-PREDICATE in a closure that operates on metadata.
+
+The returned closure takes a metadata object as argument and then
+calls TOKEN-PREDICATE on its token
+slot (`phpinspect-meta-

[nongnu] elpa/dockerfile-mode 4d893bd2da: Add new `dockerfile-build-extra-options` defcustom.

2024-09-14 Thread ELPA Syncer
branch: elpa/dockerfile-mode
commit 4d893bd2da15833ce056332e6c972d5d93e78f04
Author: pataquets 
Commit: Drew Csillag 

Add new `dockerfile-build-extra-options` defcustom.
---
 dockerfile-mode.el | 14 +-
 1 file changed, 13 insertions(+), 1 deletion(-)

diff --git a/dockerfile-mode.el b/dockerfile-mode.el
index bb3147f683..c3f02b4f39 100644
--- a/dockerfile-mode.el
+++ b/dockerfile-mode.el
@@ -72,6 +72,17 @@ Each element of the list will be passed as a separate
   :group 'dockerfile
   :type 'string)
 
+(defcustom dockerfile-build-extra-options nil
+  "Extra command-line options to send to docker build.
+
+Use this variable to add custom command-line switches not covered by
+existing dockerfile-build-* variables.
+
+Example:
+(setq-default dockerfile-build-extra-options \"--network host\")"
+  :group 'dockerfile
+  :type 'string)
+
 (defcustom dockerfile-use-buildkit nil
   "Use Docker buildkit for building images?
 
@@ -219,7 +230,7 @@ The shell command used to build the image is:
   (save-buffer)
 (compilation-start
 (format
-"%s%s%s build %s %s %s %s %s --progress %s -f %s %s"
+"%s%s%s build %s %s %s %s %s --progress %s %s -f %s %s"
 (if dockerfile-use-buildkit "DOCKER_BUILDKIT=1 " "")
 (if dockerfile-use-sudo "sudo " "")
 dockerfile-mode-command
@@ -229,6 +240,7 @@ The shell command used to build the image is:
 (dockerfile-tag-string image-name)
 (dockerfile-build-arg-string)
 dockerfile-build-progress
+(or dockerfile-build-extra-options "")
 (shell-quote-argument (dockerfile-standard-filename
   (or (file-remote-p (buffer-file-name) 
'localname)
   (buffer-file-name



[nongnu] elpa/gnuplot 86c40ebf3c 2/3: CI: Test Emacs 29

2024-09-14 Thread ELPA Syncer
branch: elpa/gnuplot
commit 86c40ebf3c2a38f5790452be722151adba953471
Author: Daniel Mendler 
Commit: Daniel Mendler 

CI: Test Emacs 29
---
 .github/workflows/test.yml | 4 
 1 file changed, 4 insertions(+)

diff --git a/.github/workflows/test.yml b/.github/workflows/test.yml
index 2f4529a108..cd6370f55d 100644
--- a/.github/workflows/test.yml
+++ b/.github/workflows/test.yml
@@ -16,6 +16,10 @@ jobs:
   - '27.2'
   - '28.1'
   - '28.2'
+  - '29.1'
+  - '29.2'
+  - '29.3'
+  - 'release-snapshot'
   - 'snapshot'
 include:
   - emacs_version: 'snapshot'



[nongnu] elpa/gnuplot d2c0355925 3/3: CI: Fixes

2024-09-14 Thread ELPA Syncer
branch: elpa/gnuplot
commit d2c035592568f08a58eff2391903bfeffa9f7733
Author: Daniel Mendler 
Commit: Daniel Mendler 

CI: Fixes
---
 .github/workflows/test.yml | 4 
 Makefile   | 3 +--
 2 files changed, 1 insertion(+), 6 deletions(-)

diff --git a/.github/workflows/test.yml b/.github/workflows/test.yml
index cd6370f55d..ad4006d198 100644
--- a/.github/workflows/test.yml
+++ b/.github/workflows/test.yml
@@ -21,16 +21,12 @@ jobs:
   - '29.3'
   - 'release-snapshot'
   - 'snapshot'
-include:
-  - emacs_version: 'snapshot'
-allow_failure: true
 steps:
 - uses: actions/checkout@v1
 - uses: actions/setup-python@v2
 - uses: purcell/setup-emacs@master
   with:
 version: ${{ matrix.emacs_version }}
-- uses: conao3/setup-cask@master
 
 - name: Install Gnuplot
   run: sudo apt update && sudo apt install gnuplot
diff --git a/Makefile b/Makefile
index 5e21cb2822..9fe445dcf3 100644
--- a/Makefile
+++ b/Makefile
@@ -4,8 +4,7 @@ LOAD = -l gnuplot \
-l gnuplot-context \
-l gnuplot-debug-context \
-l gnuplot-gui \
-   -l gnuplot-tests \
-   -l gnuplot-test-context
+   -l gnuplot-tests
 
 .PHONY: all default clean
 



[nongnu] elpa/gnuplot updated (4c6b18f71f -> d2c0355925)

2024-09-14 Thread ELPA Syncer
elpasync pushed a change to branch elpa/gnuplot.

  from  4c6b18f71f rename duplicate "gnuplot-comment-with-single-quotes" 
(#83)
   new  235ba76c35 Fix docstring compilation warnings
   new  86c40ebf3c CI: Test Emacs 29
   new  d2c0355925 CI: Fixes


Summary of changes:
 .github/workflows/test.yml |  8 +++---
 Makefile   |  3 +--
 gnuplot-context.el |  2 +-
 gnuplot-gui.el | 62 +++---
 gnuplot.el |  8 +++---
 5 files changed, 41 insertions(+), 42 deletions(-)



[nongnu] elpa/hyperdrive b38e87aa7e: Fix (h/restart): Provide format to with-demoted-errors

2024-09-14 Thread ELPA Syncer
branch: elpa/hyperdrive
commit b38e87aa7e1475dc41e9cd42754d42e97f59cf3d
Author: Jonas Bernoulli 
Commit: Jonas Bernoulli 

Fix (h/restart): Provide format to with-demoted-errors

It works without, but the compiler complains.
---
 hyperdrive.el | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/hyperdrive.el b/hyperdrive.el
index 08f48bda6d..793d028ecf 100644
--- a/hyperdrive.el
+++ b/hyperdrive.el
@@ -145,7 +145,7 @@ which see."
   ;; NOTE: Demote errors to continue execution in case the gateway is
   ;; stopped/stopping.  Don't pass FORMAT to `with-demoted-errors' since the
   ;; errors `h/stop' may signal are already prefixed with "Hyperdrive".
-  (with-demoted-errors (h/stop))
+  (with-demoted-errors "Hyperdrive: %S" (h/stop))
   (with-timeout (10 (h/error "Timed out waiting for gateway to stop"))
 (cl-loop while (h/gateway-live-p)
  do (sleep-for 0.2)))



[nongnu] elpa/gnuplot 235ba76c35 1/3: Fix docstring compilation warnings

2024-09-14 Thread ELPA Syncer
branch: elpa/gnuplot
commit 235ba76c358d9db5b10f177552f5f8deeef74df5
Author: Daniel Mendler 
Commit: Daniel Mendler 

Fix docstring compilation warnings
---
 gnuplot-context.el |  2 +-
 gnuplot-gui.el | 62 +++---
 gnuplot.el |  8 +++
 3 files changed, 36 insertions(+), 36 deletions(-)

diff --git a/gnuplot-context.el b/gnuplot-context.el
index dfa20195d3..6b49ea7850 100644
--- a/gnuplot-context.el
+++ b/gnuplot-context.el
@@ -2191,7 +2191,7 @@ provide more useful completions and help suggestions for 
built-in
 keywords and functions by parsing each command as you type.  It
 attempts to take into account Gnuplot's many abbreviated
 keywords.  For example, with point at the end of a line reading
-\"plot 'datafile' w \", typing \\[completion-at-point] will pop
+\"plot \\='datafile\\=' w \", typing \\[completion-at-point] will pop
 up a list of plotting styles.
 
 Key bindings:
diff --git a/gnuplot-gui.el b/gnuplot-gui.el
index 6276e8b6cc..ebcb754d6e 100644
--- a/gnuplot-gui.el
+++ b/gnuplot-gui.el
@@ -597,9 +597,9 @@ See the doc-string for `gnuplot-gui-all-types'.")
 
 (defcustom gnuplot-gui-plot-splot-fit-style 'simple
   "Control the complexity of the GUI display for plot, splot, and fit.
-The values are 'simple, which causes a limited set of plot, splot, or
-fit options to be displayed, and 'complete, which attempts to display
-all options.  The 'complete setting is prone to making errors when
+The values are \\='simple, which causes a limited set of plot, splot, or
+fit options to be displayed, and \\='complete, which attempts to display
+all options.  The \\='complete setting is prone to making errors when
 parsing values already in the script buffer."
   :group 'gnuplot-gui
   :type '(radio (const :tag "Simple listing"   simple)
@@ -745,54 +745,54 @@ TAG is the name used on the widget and indicates one of 
the options
 for this command, set option, or terminal type.
 
 TYPE is one of
- 'list   a menu-list of strings
- 'list*  a menu-list of strings with a prefix
- 'number a number with an optional prefix
- 'taglike number but must be the first argument
- 'fontsize   like number but must be the last argument
- 'range  a pair of numbers like [#,#] or [#:#]
- 'pair   a pair of numbers with no punctuation and a prefix
- 'file   a quoted string and a file browser
- 'string a quoted string with an optional prefix
- 'string*an unquoted string with a prefix
- 'format a quoted string and an info-link to (gnuplot)format
- 'labels an array as needed for xtics, ytics, etc
- 'position   2 or 3 comma separated numbers with an optional prefix
+ \\='list   a menu-list of strings
+ \\='list*  a menu-list of strings with a prefix
+ \\='number a number with an optional prefix
+ \\='taglike number but must be the first argument
+ \\='fontsize   like number but must be the last argument
+ \\='range  a pair of numbers like [#,#] or [#:#]
+ \\='pair   a pair of numbers with no punctuation and a prefix
+ \\='file   a quoted string and a file browser
+ \\='string a quoted string with an optional prefix
+ \\='string*an unquoted string with a prefix
+ \\='format a quoted string and an info-link to (gnuplot)format
+ \\='labels an array as needed for xtics, ytics, etc
+ \\='position   2 or 3 comma separated numbers with an optional prefix
 
 DEFAULT is the default value for this option.  Note that the default
-for 'range and 'pair is a cons cell and the default for 'labels is a
+for \\='range and \\='pair is a cons cell and the default for \\='labels is a
 list.  For most things, the best choice of DEFAULT is a string of
 white space or a cons cell of two strings of white space.  Strings of
 white space are better defaults than empty strings or nil.
 
 The value of REST depends upon TYPE:
 
-  For 'list &REST is the list of options that will go into the
-  'list*   menu-button.  This can also be a symbol which
+  For \\='list &REST is the list of options that will go into the
+  \\='list*   menu-button.  This can also be a symbol which
evaluates to a list containing the options to go into
the menu-button.  This list variable must contain the
DEFAULT.
-  For 'numberREST is the prefix string (if it exists) for that number.
-  For 'range REST is the separator, \":\" for plot ranges and
+  For \\='numberREST is the prefix string (if it exists) for that number.
+  For \\='range REST is the separator, \":\" for plot ranges and
\",\" for plot dimensions (see for example the tgif
terminal type)
-  For 'string &  REST may a number denoting the width of the editable-text
-  'string* field or it may be a string denoting a prefix.  By

[nongnu] elpa/racket-mode f0f1a7bde1: racket-unicode input method: change "oint" to "Oint"

2024-09-14 Thread ELPA Syncer
branch: elpa/racket-mode
commit f0f1a7bde1b1e15188b076967dbd5e8b90ab1056
Author: Ben Carriel 
Commit: GitHub 

racket-unicode input method: change "oint" to "Oint"
---
 racket-unicode-input-method.el | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/racket-unicode-input-method.el b/racket-unicode-input-method.el
index 9086d989a7..0bb1dd9073 100644
--- a/racket-unicode-input-method.el
+++ b/racket-unicode-input-method.el
@@ -130,7 +130,7 @@ can turn it off by setting `input-method-highlight-flag' to 
nil."
  ("prod "   ["∏"])
  ("coprod"  ["∐"])
  ("integrate "  ["∫"])
- ("oint "   ["∮"])
+ ("Oint "   ["∮"])
  ("vee "["∨"])
  ("wedge "  ["∧"])
  ("follows "["∘"])



[elpa] externals/transient updated (fb88f803e8 -> 5a41cd581e)

2024-09-14 Thread Jonas Bernoulli via
tarsius pushed a change to branch externals/transient.

  from  fb88f803e8 transient--parse-suffix: Clarify clause, removing dead 
code
   new  6b62e6cd1b manual: Fix pastos and version
   new  5a41cd581e transient-active-prefix: Accept symbol or list of symbols


Summary of changes:
 CHANGELOG   |  5 +
 docs/transient.org  |  8 
 docs/transient.texi | 14 +++---
 lisp/transient.el   |  8 
 4 files changed, 20 insertions(+), 15 deletions(-)



[elpa] externals/transient 5a41cd581e 2/2: transient-active-prefix: Accept symbol or list of symbols

2024-09-14 Thread Jonas Bernoulli via
branch: externals/transient
commit 5a41cd581e051fb5acf0444b02b926070073b89f
Author: Joseph Turner 
Commit: Jonas Bernoulli 

transient-active-prefix: Accept symbol or list of symbols
---
 CHANGELOG   | 5 +
 docs/transient.org  | 6 +++---
 docs/transient.texi | 6 +++---
 lisp/transient.el   | 8 
 4 files changed, 15 insertions(+), 10 deletions(-)

diff --git a/CHANGELOG b/CHANGELOG
index ae5379ddc6..3d6eff4af8 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -1,4 +1,9 @@
 # -*- mode: org -*-
+* v0.7.6UNRELEASED
+
+- ~transient-active-prefix~ now accepts a single prefix symbol, in place
+  of a list of such symbols.  #307
+
 * v0.7.52024-09-01
 
 - Updated tooling.
diff --git a/docs/transient.org b/docs/transient.org
index 3de17759b7..c00ca6b7fe 100644
--- a/docs/transient.org
+++ b/docs/transient.org
@@ -1308,9 +1308,9 @@ function, which for infix arguments serves about the same 
purpose as
   is current, this function is also suitable for use in asynchronous
   code, such as timers and callbacks (this function's main use-case).
 
-  If optional PREFIXES is non-~nil~, it must be a list of prefix command
-  symbols, in which case the active transient object is only returned
-  if it matches one of the PREFIXES.
+  If optional PREFIXES is non-~nil~, it must be a prefix command symbol
+  or a list of symbols, in which case the active transient object is
+  only returned if it matches one of the PREFIXES.
 
 ** Transient State
 #+cindex: transient state
diff --git a/docs/transient.texi b/docs/transient.texi
index 02ff00f41c..a69e8d0732 100644
--- a/docs/transient.texi
+++ b/docs/transient.texi
@@ -1510,9 +1510,9 @@ that is run directly by a command that is invoked while a 
transient
 is current, this function is also suitable for use in asynchronous
 code, such as timers and callbacks (this function's main use-case).
 
-If optional PREFIXES is non-@code{nil}, it must be a list of prefix command
-symbols, in which case the active transient object is only returned
-if it matches one of the PREFIXES@.
+If optional PREFIXES is non-@code{nil}, it must be a prefix command symbol
+or a list of symbols, in which case the active transient object is
+only returned if it matches one of the PREFIXES@.
 @end defun
 
 @node Transient State
diff --git a/lisp/transient.el b/lisp/transient.el
index 787f15a2cb..8be07d0e91 100644
--- a/lisp/transient.el
+++ b/lisp/transient.el
@@ -1593,13 +1593,13 @@ that is run directly by a command that is invoked while 
a transient
 is current, this function is also suitable for use in asynchronous
 code, such as timers and callbacks (this function's main use-case).
 
-If optional PREFIXES is non-nil, it must be a list of prefix command
-symbols, in which case the active transient object is only returned
-if it matches one of the PREFIXES."
+If optional PREFIXES is non-nil, it must be a prefix command symbol
+or a list of symbols, in which case the active transient object is
+only returned if it matches one of PREFIXES."
   (and transient--showp
transient--prefix
(or (not prefixes)
-   (memq (oref transient--prefix command) prefixes))
+   (memq (oref transient--prefix command) (ensure-list prefixes)))
(or (memq 'transient--pre-command pre-command-hook)
(and (memq t pre-command-hook)
 (memq 'transient--pre-command



[elpa] externals/transient 6b62e6cd1b 1/2: manual: Fix pastos and version

2024-09-14 Thread Jonas Bernoulli via
branch: externals/transient
commit 6b62e6cd1ba4b8a73ef8b803ef7cd579ef07d6fa
Author: Jonas Bernoulli 
Commit: Jonas Bernoulli 

manual: Fix pastos and version
---
 docs/transient.org  |  4 ++--
 docs/transient.texi | 10 +-
 2 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/docs/transient.org b/docs/transient.org
index 7698930432..3de17759b7 100644
--- a/docs/transient.org
+++ b/docs/transient.org
@@ -1296,7 +1296,7 @@ function, which for infix arguments serves about the same 
purpose as
   returned value is a ~transient-prefix~ object, which holds information
   associated with the transient prefix command.
 
-- Variable: transient-active-prefix ::
+- Function: transient-active-prefix ::
 
   This function returns the active transient object.  Return ~nil~ if
   there is no active transient, if the transient buffer isn't shown,
@@ -1310,7 +1310,7 @@ function, which for infix arguments serves about the same 
purpose as
 
   If optional PREFIXES is non-~nil~, it must be a list of prefix command
   symbols, in which case the active transient object is only returned
-  if it matches one of the PREFIXES."
+  if it matches one of the PREFIXES.
 
 ** Transient State
 #+cindex: transient state
diff --git a/docs/transient.texi b/docs/transient.texi
index 5ec765351a..02ff00f41c 100644
--- a/docs/transient.texi
+++ b/docs/transient.texi
@@ -31,7 +31,7 @@ General Public License for more details.
 @finalout
 @titlepage
 @title Transient User and Developer Manual
-@subtitle for version 0.7.4
+@subtitle for version 0.7.5
 @author Jonas Bernoulli
 @page
 @vskip 0pt plus 1filll
@@ -53,7 +53,7 @@ resource to get over that hurdle is Psionic K's interactive 
tutorial,
 available at @uref{https://github.com/positron-solutions/transient-showcase}.
 
 @noindent
-This manual is for Transient version 0.7.4.
+This manual is for Transient version 0.7.5.
 
 @insertcopying
 @end ifnottex
@@ -1499,7 +1499,7 @@ returned value is a @code{transient-prefix} object, which 
holds information
 associated with the transient prefix command.
 @end defvar
 
-@defvar transient-active-prefix
+@defun transient-active-prefix
 This function returns the active transient object.  Return @code{nil} if
 there is no active transient, if the transient buffer isn't shown,
 and while the active transient is suspended (e.g., while the
@@ -1512,8 +1512,8 @@ code, such as timers and callbacks (this function's main 
use-case).
 
 If optional PREFIXES is non-@code{nil}, it must be a list of prefix command
 symbols, in which case the active transient object is only returned
-if it matches one of the PREFIXES."
-@end defvar
+if it matches one of the PREFIXES@.
+@end defun
 
 @node Transient State
 @section Transient State



[elpa] externals/phpinspect 1cdfd9aaf6: Bump version to 2.1.0

2024-09-14 Thread ELPA Syncer
branch: externals/phpinspect
commit 1cdfd9aaf6fee003554d3c7832224455ddd9eaa1
Author: Hugo Thunnissen 
Commit: Hugo Thunnissen 

Bump version to 2.1.0
---
 phpinspect-autoload.el |  2 +-
 phpinspect-bmap.el |  2 +-
 phpinspect-buffer.el   |  2 +-
 phpinspect-cache.el|  2 +-
 phpinspect-changeset.el|  2 +-
 phpinspect-completion.el   |  2 +-
 phpinspect-edtrack.el  |  2 +-
 phpinspect-eldoc.el|  2 +-
 phpinspect-fs.el   |  2 +-
 phpinspect-imports.el  |  2 +-
 phpinspect-index.el|  2 +-
 phpinspect-meta.el |  2 +-
 phpinspect-method-cell.el  |  2 +-
 phpinspect-parse-context.el|  2 +-
 phpinspect-parser.el   |  2 +-
 phpinspect-pipeline.el |  2 +-
 phpinspect-project-struct.el   |  2 +-
 phpinspect-project.el  |  2 +-
 phpinspect-property-cell.el|  2 +-
 phpinspect-queue.el|  2 +-
 phpinspect-resolve.el  |  2 +-
 phpinspect-resolvecontext.el   |  2 +-
 phpinspect-serialize.el|  2 +-
 phpinspect-splayt.el   |  2 +-
 phpinspect-suggest.el  |  2 +-
 phpinspect-toc.el  |  2 +-
 phpinspect-token-predicates.el |  2 +-
 phpinspect-type.el |  2 +-
 phpinspect-typedef.el  |  2 +-
 phpinspect-util.el |  2 +-
 phpinspect-worker.el   |  2 +-
 phpinspect.el  | 21 -
 32 files changed, 51 insertions(+), 32 deletions(-)

diff --git a/phpinspect-autoload.el b/phpinspect-autoload.el
index 78adb664ab..3c110217e5 100644
--- a/phpinspect-autoload.el
+++ b/phpinspect-autoload.el
@@ -4,7 +4,7 @@
 
 ;; Author: Hugo Thunnissen 
 ;; Keywords: php, languages, tools, convenience
-;; Version: 2.0.1
+;; Version: 2.1.0
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
diff --git a/phpinspect-bmap.el b/phpinspect-bmap.el
index f1e2c9671f..e5a5db65b3 100644
--- a/phpinspect-bmap.el
+++ b/phpinspect-bmap.el
@@ -4,7 +4,7 @@
 
 ;; Author: Hugo Thunnissen 
 ;; Keywords: php, languages, tools, convenience
-;; Version: 2.0.1
+;; Version: 2.1.0
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
diff --git a/phpinspect-buffer.el b/phpinspect-buffer.el
index 4827be6c5f..17738161d0 100644
--- a/phpinspect-buffer.el
+++ b/phpinspect-buffer.el
@@ -4,7 +4,7 @@
 
 ;; Author: Hugo Thunnissen 
 ;; Keywords: php, languages, tools, convenience
-;; Version: 2.0.1
+;; Version: 2.1.0
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
diff --git a/phpinspect-cache.el b/phpinspect-cache.el
index 06edd32284..aa8dac8e5f 100644
--- a/phpinspect-cache.el
+++ b/phpinspect-cache.el
@@ -4,7 +4,7 @@
 
 ;; Author: Hugo Thunnissen 
 ;; Keywords: php, languages, tools, convenience
-;; Version: 2.0.1
+;; Version: 2.1.0
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
diff --git a/phpinspect-changeset.el b/phpinspect-changeset.el
index e51b1b7a88..df26aaa435 100644
--- a/phpinspect-changeset.el
+++ b/phpinspect-changeset.el
@@ -4,7 +4,7 @@
 
 ;; Author: Hugo Thunnissen 
 ;; Keywords: php, languages, tools, convenience
-;; Version: 2.0.1
+;; Version: 2.1.0
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
diff --git a/phpinspect-completion.el b/phpinspect-completion.el
index 1ca321e025..8b2bda8693 100644
--- a/phpinspect-completion.el
+++ b/phpinspect-completion.el
@@ -4,7 +4,7 @@
 
 ;; Author: Hugo Thunnissen 
 ;; Keywords: php, languages, tools, convenience
-;; Version: 2.0.1
+;; Version: 2.1.0
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
diff --git a/phpinspect-edtrack.el b/phpinspect-edtrack.el
index 3f51dc642d..1d9a5f87c8 100644
--- a/phpinspect-edtrack.el
+++ b/phpinspect-edtrack.el
@@ -4,7 +4,7 @@
 
 ;; Author: Hugo Thunnissen 
 ;; Keywords: php, languages, tools, convenience
-;; Version: 2.0.1
+;; Version: 2.1.0
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
diff --git a/phpinspect-eldoc.el b/phpinspect-eldoc.el
index 9143621c04..9ba5f4f18a 100644
--- a/phpinspect-eldoc.el
+++ b/phpinspect-eldoc.el
@@ -4,7 +4,7 @@
 
 ;; Author: Hugo Thunnissen 
 ;; Keywords: php, languages, tools, convenience
-;; Version: 2.0.1
+;; Version: 2.1.0
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
diff --git a/phpinspect-fs.el b/

[nongnu] elpa/bash-completion updated (53d503a119 -> 0f4f7ab456)

2024-09-14 Thread ELPA Syncer
elpasync pushed a change to branch elpa/bash-completion.

  from  53d503a119 Mention mistty in README.md
   new  784dee625f Remove trailing whitespace in README.md
   new  55e43a9654 Remove readability in the surrounding of links in 
README.md
   new  0f4f7ab456 Merge pull request #73 from tarsiiformes/cosmetics


Summary of changes:
 README.md | 42 +++---
 1 file changed, 23 insertions(+), 19 deletions(-)



[nongnu] elpa/bash-completion 0f4f7ab456 3/3: Merge pull request #73 from tarsiiformes/cosmetics

2024-09-14 Thread ELPA Syncer
branch: elpa/bash-completion
commit 0f4f7ab45648d5fed0f8a67526c1a6902754f84c
Merge: 53d503a119 55e43a9654
Author: Stephane Zermatten 
Commit: GitHub 

Merge pull request #73 from tarsiiformes/cosmetics

Minor whitespace and link cosmetics
---
 README.md | 42 +++---
 1 file changed, 23 insertions(+), 19 deletions(-)

diff --git a/README.md b/README.md
index 7cdd86ea00..3e334dc259 100644
--- a/README.md
+++ b/README.md
@@ -13,17 +13,17 @@ Bash completion for Emacs:
 - is configurable through programmable bash completion
 - works on remote shells, through TRAMP.
 
-However, bash-completion.el only works with bash. If you run 
-other shells or other interactive programs that support completion, 
-bash-completion will not be able to help. 
+However, bash-completion.el only works with bash. If you run
+other shells or other interactive programs that support completion,
+bash-completion will not be able to help.
 
-A more powerful alternative to bash-completion.el is [MisTTY], 
-as it works with all shells and most interactive programs that support 
-completion. On the other hand, MisTTY cannot integrate with Emacs 
-completion and is not able to provide completion in shell-command 
-prompts nor in eshell mode. 
+A more powerful alternative to bash-completion.el is [MisTTY],
+as it works with all shells and most interactive programs that support
+completion. On the other hand, MisTTY cannot integrate with Emacs
+completion and is not able to provide completion in shell-command
+prompts nor in eshell mode.
 
-> [!NOTE]  
+> [!NOTE]
 > While I'm still maintaining bash-completion.el, I've switched
 > to [MisTTY] for day-to-day operation, so that package is more
 > likely to receive updates. -- szermatt
@@ -115,25 +115,29 @@ the following:
 
 * Does bash behave differently when run outside of Emacs? If not, check
   your shell configuration.
-* Call `M-x bash-completion-debug` and look at the `output-buffer` 
-  section. Does it  match the expected set of completion? If yes, 
-  it might be a display problem. Are you using a completion engine 
-  other than the default, such as ivy or helm? Try turning it off to 
-  confirm, then [file a bug][new_issue]
-* If all else fails, [file a bug][new_issue]. Please include the output 
+* Call `M-x bash-completion-debug` and look at the `output-buffer`
+  section. Does it  match the expected set of completion? If yes,
+  it might be a display problem. Are you using a completion engine
+  other than the default, such as ivy or helm? Try turning it off to
+  confirm, then [file a bug][new_issue].
+* If all else fails, [file a bug][new_issue]. Please include the output
   of `M-x bash-completion-debug`, the command you're trying to use
   and the function or package providing completion for that command and
-  where to download it. 
+  where to download it.
 
 ## CONTRIBUTING
 
-To report bugs, features or even to ask questions, please open an 
[issue](https://github.com/szermatt/emacs-bash-completion/issues). To 
contribute code or documentation, please open a [pull 
request](https://github.com/szermatt/emacs-bash-completion/pulls). 
+To report bugs, features or even to ask questions, please open an
+[issue][issues].  To contribute code or documentation, please open a
+[pull request][pull-requests].
 
-See [CONTRIBUTING.md](CONTRIBUTING.md) for more details. 
+See [CONTRIBUTING.md](CONTRIBUTING.md) for more details.
 
 ## COMPATIBILITY
 
 bash-completion.el is known to work with Bash 4.2 and later and Bash
-5, on Emacs, starting with version 25.3, under Linux and OSX. 
+5, on Emacs, starting with version 25.3, under Linux and OSX.
 
 [new_issue]: https://github.com/szermatt/emacs-bash-completion/issues/new
+[issues]: https://github.com/szermatt/emacs-bash-completion/issues)
+[pull-requests]: (https://github.com/szermatt/emacs-bash-completion/pulls)



[nongnu] elpa/bash-completion 55e43a9654 2/3: Remove readability in the surrounding of links in README.md

2024-09-14 Thread ELPA Syncer
branch: elpa/bash-completion
commit 55e43a9654574e1917eaab7e7978dffbaaaf84fd
Author: Jonas Bernoulli 
Commit: Jonas Bernoulli 

Remove readability in the surrounding of links in README.md
---
 README.md | 8 ++--
 1 file changed, 6 insertions(+), 2 deletions(-)

diff --git a/README.md b/README.md
index c51e90f00f..3e334dc259 100644
--- a/README.md
+++ b/README.md
@@ -119,7 +119,7 @@ the following:
   section. Does it  match the expected set of completion? If yes,
   it might be a display problem. Are you using a completion engine
   other than the default, such as ivy or helm? Try turning it off to
-  confirm, then [file a bug][new_issue]
+  confirm, then [file a bug][new_issue].
 * If all else fails, [file a bug][new_issue]. Please include the output
   of `M-x bash-completion-debug`, the command you're trying to use
   and the function or package providing completion for that command and
@@ -127,7 +127,9 @@ the following:
 
 ## CONTRIBUTING
 
-To report bugs, features or even to ask questions, please open an 
[issue](https://github.com/szermatt/emacs-bash-completion/issues). To 
contribute code or documentation, please open a [pull 
request](https://github.com/szermatt/emacs-bash-completion/pulls).
+To report bugs, features or even to ask questions, please open an
+[issue][issues].  To contribute code or documentation, please open a
+[pull request][pull-requests].
 
 See [CONTRIBUTING.md](CONTRIBUTING.md) for more details.
 
@@ -137,3 +139,5 @@ bash-completion.el is known to work with Bash 4.2 and later 
and Bash
 5, on Emacs, starting with version 25.3, under Linux and OSX.
 
 [new_issue]: https://github.com/szermatt/emacs-bash-completion/issues/new
+[issues]: https://github.com/szermatt/emacs-bash-completion/issues)
+[pull-requests]: (https://github.com/szermatt/emacs-bash-completion/pulls)



[nongnu] elpa/bash-completion 784dee625f 1/3: Remove trailing whitespace in README.md

2024-09-14 Thread ELPA Syncer
branch: elpa/bash-completion
commit 784dee625f0fa86f667d07151b98cba7ef9598ab
Author: Jonas Bernoulli 
Commit: Jonas Bernoulli 

Remove trailing whitespace in README.md
---
 README.md | 36 ++--
 1 file changed, 18 insertions(+), 18 deletions(-)

diff --git a/README.md b/README.md
index 7cdd86ea00..c51e90f00f 100644
--- a/README.md
+++ b/README.md
@@ -13,17 +13,17 @@ Bash completion for Emacs:
 - is configurable through programmable bash completion
 - works on remote shells, through TRAMP.
 
-However, bash-completion.el only works with bash. If you run 
-other shells or other interactive programs that support completion, 
-bash-completion will not be able to help. 
+However, bash-completion.el only works with bash. If you run
+other shells or other interactive programs that support completion,
+bash-completion will not be able to help.
 
-A more powerful alternative to bash-completion.el is [MisTTY], 
-as it works with all shells and most interactive programs that support 
-completion. On the other hand, MisTTY cannot integrate with Emacs 
-completion and is not able to provide completion in shell-command 
-prompts nor in eshell mode. 
+A more powerful alternative to bash-completion.el is [MisTTY],
+as it works with all shells and most interactive programs that support
+completion. On the other hand, MisTTY cannot integrate with Emacs
+completion and is not able to provide completion in shell-command
+prompts nor in eshell mode.
 
-> [!NOTE]  
+> [!NOTE]
 > While I'm still maintaining bash-completion.el, I've switched
 > to [MisTTY] for day-to-day operation, so that package is more
 > likely to receive updates. -- szermatt
@@ -115,25 +115,25 @@ the following:
 
 * Does bash behave differently when run outside of Emacs? If not, check
   your shell configuration.
-* Call `M-x bash-completion-debug` and look at the `output-buffer` 
-  section. Does it  match the expected set of completion? If yes, 
-  it might be a display problem. Are you using a completion engine 
-  other than the default, such as ivy or helm? Try turning it off to 
+* Call `M-x bash-completion-debug` and look at the `output-buffer`
+  section. Does it  match the expected set of completion? If yes,
+  it might be a display problem. Are you using a completion engine
+  other than the default, such as ivy or helm? Try turning it off to
   confirm, then [file a bug][new_issue]
-* If all else fails, [file a bug][new_issue]. Please include the output 
+* If all else fails, [file a bug][new_issue]. Please include the output
   of `M-x bash-completion-debug`, the command you're trying to use
   and the function or package providing completion for that command and
-  where to download it. 
+  where to download it.
 
 ## CONTRIBUTING
 
-To report bugs, features or even to ask questions, please open an 
[issue](https://github.com/szermatt/emacs-bash-completion/issues). To 
contribute code or documentation, please open a [pull 
request](https://github.com/szermatt/emacs-bash-completion/pulls). 
+To report bugs, features or even to ask questions, please open an 
[issue](https://github.com/szermatt/emacs-bash-completion/issues). To 
contribute code or documentation, please open a [pull 
request](https://github.com/szermatt/emacs-bash-completion/pulls).
 
-See [CONTRIBUTING.md](CONTRIBUTING.md) for more details. 
+See [CONTRIBUTING.md](CONTRIBUTING.md) for more details.
 
 ## COMPATIBILITY
 
 bash-completion.el is known to work with Bash 4.2 and later and Bash
-5, on Emacs, starting with version 25.3, under Linux and OSX. 
+5, on Emacs, starting with version 25.3, under Linux and OSX.
 
 [new_issue]: https://github.com/szermatt/emacs-bash-completion/issues/new



[elpa] externals/dape 50a62a11ed 2/2: Add reverse zapp like parsing with "-"

2024-09-14 Thread ELPA Syncer
branch: externals/dape
commit 50a62a11edbf9465d48cf70a5eeb4d99cb83d4de
Author: Daniel Pettersson 
Commit: Daniel Pettersson 

Add reverse zapp like parsing with "-"

Let - act as an reader macro for applying options :env :program :args
---
 dape.el | 27 ---
 1 file changed, 24 insertions(+), 3 deletions(-)

diff --git a/dape.el b/dape.el
index 5b6984752e..9d478db4a2 100644
--- a/dape.el
+++ b/dape.el
@@ -5078,8 +5078,28 @@ If LOOSE-PARSING is non nil ignore arg parsing failures."
 (string-trim)
 (string-empty-p)
 (not))
-(push (read (current-buffer))
-  read-config))
+(let ((thing (read (current-buffer
+  (cond
+   ((eq thing '-)
+(cl-loop
+ with command = (split-string-shell-command
+ (buffer-substring (point) (point-max)))
+ with setvar = "\\`\\([A-Za-z_][A-Za-z0-9_]*\\)=\\(.*\\)\\'"
+ for cell on command for (program . args) = cell
+ if (string-match setvar program)
+ append `(,(intern (concat ":" (match-string 1 program)))
+  ,(match-string 2 program))
+ into env and for program = nil
+ when (or (and (not program) (not args)) program) do
+ (setq read-config
+   (append (nreverse
+(append (when program `(:program ,program))
+(when args `(:args ,(apply 'vector 
args)))
+(when env `(:env ,env
+   read-config))
+ (throw 'done nil)))
+   (t
+(push thing read-config)
 (error
  (unless loose-parsing
(user-error "Unable to parse options %s"
@@ -5171,7 +5191,8 @@ nil."
   (mapcar (lambda (suggestion) (format "%s " suggestion))
   dape--minibuffer-suggestions
  ;; Complete config args
- ((and (alist-get key dape-configs)
+ ((and (not (plist-member args '-))
+   (alist-get key dape-configs)
(or (and (plistp args)
 (thing-at-point 'whitespace))
(cl-loop with p = (point)



[elpa] externals/dape updated (22dcbbaa1e -> 50a62a11ed)

2024-09-14 Thread ELPA Syncer
elpasync pushed a change to branch externals/dape.

  from  22dcbbaa1e Fix formatting
   new  fb7d5247e6 Fix formatting
   new  50a62a11ed Add reverse zapp like parsing with "-"


Summary of changes:
 dape.el | 40 
 1 file changed, 28 insertions(+), 12 deletions(-)



[elpa] externals/dape fb7d5247e6 1/2: Fix formatting

2024-09-14 Thread ELPA Syncer
branch: externals/dape
commit fb7d5247e670fb89f7065102d1df3bf5643912ae
Author: Daniel Pettersson 
Commit: Daniel Pettersson 

Fix formatting
---
 dape.el | 13 -
 1 file changed, 4 insertions(+), 9 deletions(-)

diff --git a/dape.el b/dape.el
index 192da3422e..5b6984752e 100644
--- a/dape.el
+++ b/dape.el
@@ -5151,15 +5151,12 @@ nil."
   (let (key args args-bounds last-p)
 (save-excursion
   (goto-char (minibuffer-prompt-end))
-  (setq key
-(ignore-errors (read (current-buffer
+  (setq key (ignore-errors (read (current-buffer
   (ignore-errors
 (while t
   (setq last-p (point))
-  (push (read (current-buffer))
-args)
-  (push (cons last-p (point))
-args-bounds
+  (push (read (current-buffer)) args)
+  (push (cons last-p (point)) args-bounds
 (setq args (nreverse args)
   args-bounds (nreverse args-bounds))
 (cond
@@ -5191,9 +5188,7 @@ nil."
for (key _) on plist by 'cddr
collect (format "%s " key)
  (t
-  (list (point) (point)
-nil
-:exclusive 'no)
+  (list (point) (point) nil :exclusive 'no)
 
 (defun dape--read-config ()
   "Read config from minibuffer.



[elpa] externals/hyperbole ae6188cbd9: Verify hyrolo--expanded-file-list is updated when a file is added (#590)

2024-09-14 Thread ELPA Syncer
branch: externals/hyperbole
commit ae6188cbd900813e0a6b1667718943a57852afaf
Author: Mats Lidell 
Commit: GitHub 

Verify hyrolo--expanded-file-list is updated when a file is added (#590)

Test marked as expected-result failed since cache currently is not
updated which seems like an error.
---
 ChangeLog|  5 +
 test/hyrolo-tests.el | 20 +++-
 2 files changed, 24 insertions(+), 1 deletion(-)

diff --git a/ChangeLog b/ChangeLog
index b2cd7d8c67..ad80593f5f 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,8 @@
+2024-09-11  Mats Lidell  
+
+* test/hyrolo-tests.el (hyrolo-tests--get-file-list): Verify
+`hyrolo--expanded-file-list' is updated when a file is added.
+
 2024-09-10  Bob Weiner  
 
 * hywiki.el (hywiki-org-make-publish-project-alist): Add
diff --git a/test/hyrolo-tests.el b/test/hyrolo-tests.el
index 1d116b1d49..6190fdfc8f 100644
--- a/test/hyrolo-tests.el
+++ b/test/hyrolo-tests.el
@@ -3,7 +3,7 @@
 ;; Author:   Mats Lidell 
 ;;
 ;; Orig-Date:19-Jun-21 at 22:42:00
-;; Last-Mod:  5-Aug-24 at 22:16:27 by Mats Lidell
+;; Last-Mod: 11-Sep-24 at 23:56:02 by Mats Lidell
 ;;
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 ;;
@@ -470,6 +470,24 @@ Match a string in the second cell."
()))
   (hy-delete-file-and-buffer tmp-file
 
+(ert-deftest hyrolo-tests--get-file-list ()
+  "Verify `hyrolo-get-file-list` includes added files."
+  :expected-result :failed
+  (let* ((folder (make-temp-file "hypb" t))
+ (prefix (expand-file-name "hypb" folder))
+ (org-file (make-temp-file prefix nil ".org"))
+ (hyrolo-file-list (list folder)))
+(unwind-protect
+(progn
+  (should (= 1 (length (hyrolo-get-file-list
+  (let ((org2-file (make-temp-file prefix nil ".org")))
+(unwind-protect
+(should (= 2 (length (hyrolo-get-file-list
+  (hy-delete-file-and-buffer org2-file
+  (dolist (f (list org-file))
+(hy-delete-file-and-buffer f))
+  (delete-directory folder
+
 ;; Outline movement tests
 (defun hyrolo-tests--level-number (section depth)
   "Generate the number for the SECTION at DEPTH.



[elpa] externals/org-modern bb048dcbca: org-modern-timestamp: Do not highlight dates in links

2024-09-14 Thread ELPA Syncer
branch: externals/org-modern
commit bb048dcbcaae19762f0c1097d27027695512fb7b
Author: Daniel Mendler 
Commit: Daniel Mendler 

org-modern-timestamp: Do not highlight dates in links
---
 org-modern.el | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/org-modern.el b/org-modern.el
index 26673b3f02..ebeee2aba5 100644
--- a/org-modern.el
+++ b/org-modern.el
@@ -486,7 +486,7 @@ the font.")
 
 (defun org-modern--timestamp ()
   "Prettify timestamps."
-  (let* ((beg (match-beginning 0))
+  (let* ((beg (1- (match-beginning 1)))
  (end (match-end 0))
  (tbeg (match-beginning 2))
  (tend (match-end 2))
@@ -787,7 +787,7 @@ whole buffer; otherwise, for the line at point."
 ((pred stringp) `(1 '(face nil display ,org-modern-keyword)))
 (_ '(0 (org-modern--keyword)))
(when org-modern-timestamp
- '(("\\(?:<\\|\\[\\)\\([0-9]\\{4\\}-[0-9]\\{2\\}-[0-9]\\{2\\}\\(?: 
[[:word:]]+\\.?\\)?\\(?: [.+-]+[0-9ymwdh/]+\\)*\\)\\(\\(?: [0-9:-]+\\)?\\(?: 
[.+-]+[0-9ymwdh/]+\\)*\\)\\(?:>\\|\\]\\)"
+ 
'(("\\(?:<\\|^\\[\\|[^]]\\[\\)\\([0-9]\\{4\\}-[0-9]\\{2\\}-[0-9]\\{2\\}\\(?: 
[[:word:]]+\\.?\\)?\\(?: [.+-]+[0-9ymwdh/]+\\)*\\)\\(\\(?: [0-9:-]+\\)?\\(?: 
[.+-]+[0-9ymwdh/]+\\)*\\)\\(?:>\\|\\]\\)"
 (0 (org-modern--timestamp)))

("<[^>]+>\\(-\\)\\(-\\)<[^>]+>\\|\\[[^]]+\\]\\(?1:-\\)\\(?2:-\\)\\[[^]]+\\]"
 (1 '(face org-modern-label display #("  " 1 2 (face (:strike-through 
t) cursor t))) t)



[nongnu] elpa/helm-core updated (1c225c18d2 -> 2d6718ef09)

2024-09-14 Thread ELPA Syncer
elpasync pushed a change to branch elpa/helm-core.

  from  1c225c18d2 helm--maybe-process-filter-one-by-one-candidate is now a 
function
  adds  2d6718ef09 Do not resize action buffer with autoresize mode

No new revisions were added by this update.

Summary of changes:
 helm-core.el | 5 -
 1 file changed, 4 insertions(+), 1 deletion(-)



[nongnu] elpa/helm 2d6718ef09: Do not resize action buffer with autoresize mode

2024-09-14 Thread ELPA Syncer
branch: elpa/helm
commit 2d6718ef0938ad193a98b60534cd5170b2a1eabd
Author: Thierry Volpiatto 
Commit: Thierry Volpiatto 

Do not resize action buffer with autoresize mode

when helm-show-action-window-other-window is enabled.
---
 helm-core.el | 5 -
 1 file changed, 4 insertions(+), 1 deletion(-)

diff --git a/helm-core.el b/helm-core.el
index 56a3070f03..3b5ca1ae4b 100644
--- a/helm-core.el
+++ b/helm-core.el
@@ -8041,7 +8041,10 @@ source or `helm-follow-input-idle-delay' or
 ;;; Auto-resize mode
 ;;
 (defun helm--autoresize-hook (&optional max-height min-height)
-  (when (helm-window)
+  (when (if (helm--show-action-window-other-window-p)
+(and (helm-window)
+ (not (get-buffer-window helm-action-buffer 'visible)))
+  (helm-window))
 (with-helm-window
   (fit-window-to-buffer nil
 (/ (* (frame-height)



[elpa] externals/consult-denote 4d32f7003c: Provide previews for commands like denote-find-link, denote-find-backlink

2024-09-14 Thread ELPA Syncer
branch: externals/consult-denote
commit 4d32f7003cb413d7b011f445a6c323545ab6de74
Author: Protesilaos Stavrou 
Commit: Protesilaos Stavrou 

Provide previews for commands like denote-find-link, denote-find-backlink

Thanks to hapst3r for suggesting something like this in issue 7:
.
---
 consult-denote.el | 13 +
 1 file changed, 13 insertions(+)

diff --git a/consult-denote.el b/consult-denote.el
index 56fb361258..dd47e844d6 100644
--- a/consult-denote.el
+++ b/consult-denote.el
@@ -135,6 +135,17 @@ Return the absolute path to the matching file."
 ;; appropriately.
 absolute-file))
 
+(defun consult-denote-select-linked-file-prompt (files)
+  "Prompt for linked file among FILES."
+  (let ((file-names (mapcar #'denote-get-file-name-relative-to-denote-directory
+files)))
+(consult--read
+ (denote--completion-table 'file file-names)
+ :state (consult--file-preview)
+ :require-match t
+ :history 'denote-link-find-file-history
+ :prompt "Find linked file")))
+
 (defun consult-denote-select-linked-file-prompt (files)
   "Prompt for Denote file among FILES."
   (let* ((default-directory denote-directory)
@@ -268,6 +279,7 @@ FILE has the same meaning as in 
`denote-org-extras-outline-prompt'."
   (add-to-list 'consult-buffer-sources source :append))
 (advice-add #'denote-file-prompt :override 
#'consult-denote-file-prompt)
 (advice-add #'denote-select-linked-file-prompt :override 
#'consult-denote-select-linked-file-prompt)
+(advice-add #'denote-select-linked-file-prompt :override 
#'consult-denote-select-linked-file-prompt)
 ;; See FIXME where this function is defined.
 (advice-add #'denote-org-extras-outline-prompt :override 
#'consult-denote-outline-prompt)
 (advice-add #'denote-silo-extras-directory-prompt :override 
#'consult-denote-silo-directory-prompt))
@@ -275,6 +287,7 @@ FILE has the same meaning as in 
`denote-org-extras-outline-prompt'."
   (setq consult-buffer-sources (delq source consult-buffer-sources)))
 (advice-remove #'denote-file-prompt #'consult-denote-file-prompt)
 (advice-remove #'denote-select-linked-file-prompt 
#'consult-denote-select-linked-file-prompt)
+(advice-remove #'denote-select-linked-file-prompt 
#'consult-denote-select-linked-file-prompt)
 (advice-remove #'denote-org-extras-outline-prompt 
#'consult-denote-outline-prompt)
 (advice-remove #'denote-silo-extras-directory-prompt 
#'consult-denote-silo-directory-prompt)))
diff --git a/phpinspect-completion.el b/phpinspect-completion.el
index b9fa8efd68..1ca321e025 100644
--- a/phpinspect-completion.el
+++ b/phpinspect-completion.el
@@ -198,22 +198,33 @@ belonging to a token that conforms with 
`phpinspect-attrib-p'"
 (cl-defmethod phpinspect-comp-strategy-supports
   ((_strat phpinspect-comp-word) (q phpinspect-completion-query)
(rctx phpinspect--resolvecontext))
-  (or
-   ;; Complete word being typed
-   (when-let ((subject (phpinspect-completion-subject-at-point
-  (phpinspect-completion-query-buffer q)
-  (phpinspect-completion-query-point q)
-  #'phpinspect-word-p)))
+  "Determine suitability of comp-word strategy to resolve Q.
+
+Words can be type names, function names and keywords.  This
+strategy is a bit special in the sense that it needs to carefully
+consider whether or not it is useful to complete words at point.
+Completing words in a comment for example, is usually not useful."
+  ;; Don't complete words when editing comments
+  (unless (seq-find (phpinspect-meta-token-predicate #'phpinspect-comment-p)
+(phpinspect-buffer-tokens-enclosing-point
+ (phpinspect-completion-query-buffer q)
+ (phpinspect-completion-query-point q)))
+(or
+ ;; Complete word being typed
+ (when-let ((subject (phpinspect-completion-subject-at-point
+  (phpinspect-completion-query-buffer q)
+  (phpinspect-completion-query-point q)
+  #'phpinspect-word-p)))
(list (phpinspect-meta-start subject) (phpinspect-meta-end subject)))
 
-   ;; Point is right after a "new" token. Complete "newable" types.
-   (when-let ((token-before (phpinspect-bmap-last-token-before-point
- (phpinspect-buffer-map
-  (phpinspect-completion-query-buffer q))
- (phpinspect-completion-query-point q)))
-  ((phpinspect-new-p (phpinspect-meta-token token-before
- (list (phpinspect-completion-query-point q)
-   (phpinspect-completion-query-point q)))
+ ;; Point is right after a "new" token. Complete "newable" types.
+ (when-let ((token-before (phpinspect-bmap-last-token-before-point
+   (phpinspect-buffer-map
+(phpinspect-completion-query-buffer q))
+   (phpinspect-completion-query-point q)))
+((phpinspect-new-p (phpinspect-meta-token token-before
+   (list (phpinspect-completion-query-point q)
+ (phpinspect-completion-query-point q)))
 
;; Point is after a scope, static, declaration, const or other keyword that
;; can precede a type or another word.
@@ -224,7 +235,7 @@ belonging to a token that conforms with 
`phpinspect-attrib-p'"
   (car (phpinspect--resolvecontext-subject rctx
 
 (list (phpinspect-completion-query-point q)
-  (phpinspect-completion-query-point q)
+  (phpinspect-completion-query-point q))
 
 (cl-defmethod phpinspect-comp-strategy-execute
   ((_strat phpinspect-comp-word) (q phpinspect-completion-query)